@@ -6,12 +6,12 @@ Net::OAuth2::AuthorizationServer - Easier implementation of an OAuth2
 Authorization Server
 
 =for html
-<a href='https://travis-ci.org/G3S/net-oauth2-authorizationserver?branch=master'><img src='https://travis-ci.org/G3S/net-oauth2-authorizationserver.svg?branch=master' alt='Build Status' /></a>
-<a href='https://coveralls.io/github/G3S/net-oauth2-authorizationserver?branch=master'><img src='https://coveralls.io/repos/github/G3S/net-oauth2-authorizationserver/badge.svg?branch=master' alt='Coverage Status' /></a>
+<a href='https://travis-ci.org/Humanstate/net-oauth2-authorizationserver?branch=master'><img src='https://travis-ci.org/Humanstate/net-oauth2-authorizationserver.svg?branch=master' alt='Build Status' /></a>
+<a href='https://coveralls.io/github/Humanstate/net-oauth2-authorizationserver?branch=master'><img src='https://coveralls.io/repos/github/Humanstate/net-oauth2-authorizationserver/badge.svg?branch=master' alt='Coverage Status' /></a>
 
 =head1 VERSION
 
-0.06
+0.07
 
 =head1 SYNOPSIS
 
@@ -43,7 +43,7 @@ use Types::Standard qw/ :all /;
 use Net::OAuth2::AuthorizationServer::AuthorizationCodeGrant;
 use Net::OAuth2::AuthorizationServer::PasswordGrant;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 GRANT TYPES
 
@@ -101,7 +101,7 @@ This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself. If you would like to contribute documentation
 or file a bug report then please raise an issue / pull request:
 
-    https://github.com/G3S/net-oauth2-authorizationserver
+    https://github.com/Humanstate/net-oauth2-authorizationserver
 
 =cut
 
